@@ -2,17 +2,23 @@
 We support module-scoped async fixtures, but only if the event loop is
 module-scoped too.
 """
+
+from __future__ import annotations
+
 import asyncio
+
 import pytest
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def event_loop():
     """A module-scoped event loop."""
-    return asyncio.new_event_loop()
+    loop = asyncio.new_event_loop()
+    yield loop
+    loop.close()
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 async def async_fixture():
     await asyncio.sleep(0.1)
     return 1
