@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 import asyncio
 
 import pytest
 
+pytest_plugins = "pytester"
+
 
 @pytest.fixture
 def dependent_fixture(event_loop):
